/*
 * @Author: zc
 * @description 司法行政监督
 */
import request from '@/utils/request';
/**
 * @description 获取司法工单中心列表
 * @param params
 * @return {*}
 */
export const getWorkList = (params: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/getorderlist',
		method: 'get',
		params
	});
};
/**
 * @description 司法工单中心列表导出
 * @param data
 * @return {*}
 */
export const judicialOrderListExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/getorderlist_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
};
/**
 * @description 列表页基础信息
 * @param params
 * @return {*}
 */
export const listBaseData = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/base-data',
		method: 'get',
		params,
	});
};
/**
 * @description 线索核实
 * @param data
 * @return {*}
 */
export const getClues = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/clue_verification',
		method: 'post',
		data,
	});
};
/**
 * @description 线索核实基础信息
 * @return {*}
 */
export const getCluesBaseData = () => {
	return request({
		url: '/api/v1/JudicialManagementOrders/treelist',
		method: 'get',
	});
};
/**
 * @description 事项分类统计
 * @param params
 * @return {*}
 */
export const eventStatistics = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/event_classification_statistics',
		method: 'get',
		params,
	});
};
/**
 * @description 事项分类统计明细
 * @param params
 * @return {*}
 */
export const eventStatisticsDetail = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/event_classification_statistics_order_list',
		method: 'get',
		params,
	});
};
/**
 * @description 事项分类统计明细导出
 * @param data
 * @return {*}
 */
export const eventStatisticsDetailExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/event_classification_statistics_order_list_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
};
/**
 * @description 区域排行统计
 * @param params
 * @return {*}
 */
export const areaStatistics = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/regional_classification_statistics',
		method: 'get',
		params,
	});
};
/**
 * @description 区域排行统计导出
 * @param data
 * @return {*}
 */
export const areaStatisticsExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/regional_classification_statistics_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
};
/**
 * @description 区域排行统计明细
 * @param params
 * @return {*}
 */
export const areaStatisticsDetail = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/regional_classification_statistics_order_list',
		method: 'get',
		params,
	});
};
/**
 * @description 区域排行统计明细导出
 * @param data
 * @return {*}
 */
export const areaStatisticsDetailExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/regional_classification_statistics_order_list_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
};
/**
 * @description 执法部门统计
 * @param params
 * @return {*}
 */
export const departmentStatistics = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_departmental_processing_statistics',
		method: 'get',
		params,
	});
};
/**
 * @description 执法部门统计导出
 * @param data
 * @return {*}
 */
export const departmentStatisticsExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_departmental_processing_statistics_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
};
/**
 * @description 执法部门统计明细
 * @param params
 * @return {*}
 */
export const departmentStatisticsDetail = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_departmental_processing_statistics_order_list',
		method: 'get',
		params,
	});
};
/**
 * @description 执法部门统计明细导出
 * @param data
 * @return {*}
 */
export const departmentStatisticsDetailExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_departmental_processing_statistics_order_list_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
};
/**
 * @description 司法部门满意度统计
 * @param params
 * @return {*}
 */
export const departmentSatisfaction = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_visit_org_satisfaction_statistics',
		method: 'get',
		params,
	});
};
/**
 * @description 司法部门满意度统计导出
 * @param data
 * @return {*}
 */
export const departmentSatisfactionExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_visit_org_satisfaction_statistics_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
};
/**
 * @description 部门满意度统计明细
 * @param params
 * @return {*}
 */
export const departmentSatisfactionDetail = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_visit_org_satisfaction_statistics_order_list',
		method: 'get',
		params,
	});
};
/**
 * @description 部门满意度统计明细导出
 * @param data
 * @return {*}
 */
export const departmentSatisfactionDetailExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_visit_org_satisfaction_statistics_order_list_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
};
/**
 * @description 获取区域信息子父级
 * @param params
 * @return {*}
 */
export const getAreaChildren = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/area/tree',
		method: 'get',
		params,
	});
};
/**
 * @description 获取执法领域统计
 * @param params
 * @return {*}
 */
export const getLawEnforcementField = (params?: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_industry_statistics_order',
		method: 'get',
		params,
	});
}
/**
 * @description 执法领域统计导出
 * @param data
 * @return {*}
 */
export const getLawEnforcementFieldExport = (data: object) => {
	return request({
		url: '/api/v1/JudicialManagementOrders/enforcement_industry_statistics_order_export',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
}