/*
 * @Author: zc
 * @description 文件管理 导入 导出
 */
import request from '@/utils/request';
import qs from 'qs';
/**
 * @description 获取模板类型
 */
export const fileTemplateType = () => {
	return request({
		url: `/api/v1/Order/import-basedata`,
		method: 'get',
	});
};
/**
 * @description 下载导入模板
 */
export const fileTemplateDownload = () => {
	return request({
		url: `/api/v1/Order/download-order-template`,
		method: 'get',
		responseType: 'blob',
		headers: { 'content-type': 'audio/mpeg' },
	});
};
/**
 * @description 导入
 * @param {object}  data
 */
export const fileImport = (data: object) => {
	return request({
		url: `/api/v1/Order/import-order`,
		method: 'post',
		headers: {
			'Content-Type': 'multipart/form-data',
		},
		data,
	});
};
/**
 * @description 下载文件
 * @param {object}  params
 */
export const fileDownload = (params: object) => {
	return request({
		url: `/api/v1/File/download-proxy`,
		method: 'get',
		responseType: 'blob',
		params,
	},{
		reduce_data_format:false
	});
};
/**
 * @description 下载文件 （文件服务）
 * @param {object}  params
 */
export const fileDownloadByUrl = (params: object) => {
	return request({
		url: `/file/downloadfile`,
		method: 'get',
		responseType: 'blob',
		params,
		baseURL: import.meta.env.VITE_API_UPLOAD_URL,
	},{
		reduce_data_format:false
	});
};
/**
 * @description 下载文件批量 （文件服务）
 * @param {object}  params
 */
export const fileDownloadBatch = (data: object) => {
	return request({
		url: `/file/downloadfile_batch`,
		method: 'post',
		responseType: 'blob',
		data,
		baseURL: import.meta.env.VITE_API_UPLOAD_URL,
		paramsSerializer: (params: any) => qs.stringify(params),
	},{
		reduce_data_format:false
	});
}