/*
 * @Author: zc
 * @description 随手拍-配置管理
 */
import request from '@/utils/request';
/**
 * @description 获取行业列表
 * @param {object} params
 */
export const getIndustryList = (params?: object) => {
	return request({
		url: `/api/v1/Industry/industry`,
		method: 'get',
		params
	});
}
/**
 * @description 获取行业列表导出
 * @param {object} data
 */
export const getIndustryListExport = (data: object) => {
	return request({
		url: '/api/v1/Industry/industry/export_excel',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
}
/**
 * @description 新增行业 修改该行业  基础信息
 * @param {object} params
 */
export const baseIndustry = (params?: object) => {
	return request({
		url: '/api/v1/Industry/basedata',
		method: 'get',
		params,
	});
}
/**
 * @description 新增行业
 * @param {object} data
 */
export const addIndustry = (data: object) => {
	return request({
		url: '/api/v1/Industry',
		method: 'post',
		data,
	});
}
/**
 * @description 获取行业详情
 * @param {string} id
 */
export const getIndustryDetail = (id: string) => {
	return request({
		url: `/api/v1/Industry/${id}`,
		method: 'get',
	});
}
/**
 * @description 修改行业
 * @param {object} data
 */
export const editIndustry = (data: object) => {
	return request({
		url: '/api/v1/Industry',
		method: 'put',
		data,
	});
}
/**
 * @description 删除行业
 * @param {object} data
 */
/*export const delIndustry = (data: object) => {
	return request({
		url: '/api/v1/Industry',
		method: 'delete',
		data,
	});
}*/
/**
 * @description 获取线索列表
 * @param {object} params
 */
export const getClueList = (params?: object) => {
	return request({
		url: '/api/v1/Industry/case',
		method: 'get',
		params,
	});
}
/**
 * @description 获取线索列表导出
 * @param {object} data
 */
export const getClueListExport = (data: object) => {
	return request({
		url: '/api/v1/Industry/case/export_excel',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
}
/**
 * @description 获取线索新增基础信息
 * @param {object} params
 */
export const baseClue = (params?: object) => {
	return request({
		url: '/api/v1/Industry/case/database',
		method: 'get',
		params,
	});
}
/**
 * @description 新增线索
 * @param {object} data
 */
export const addClue = (data: object) => {
	return request({
		url: '/api/v1/Industry/case',
		method: 'post',
		data,
	});
}
/**
 * @description 获取线索详情
 * @param {string} id
 */
export const getClueDetail = (id: string) => {
	return request({
		url: `/api/v1/Industry/case/${id}`,
		method: 'get',
	});
}
/**
 * @description 更新线索
 * @param {object} data
 */
export const editClue = (data: object) => {
	return request({
		url: '/api/v1/Industry/case',
		method: 'put',
		data,
	});
}
/**
 * @description 获取审批短信模板列表
 * @param {object} params
 */
export const getSmsList = (params?: object) => {
	return request({
		url: '/api/v1/Industry/sms_template',
		method: 'get',
		params,
	});
}
/**
 * @description 审批短信模板列表导出
 * @param {object} data
 */
export const getSmsListExport = (data: object) => {
	return request({
		url: '/api/v1/Industry/sms_template/export_excel',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
}
/**
 * @description 新增短信模板
 * @param {object} data
 */
export const addSms = (data: object) => {
	return request({
		url: '/api/v1/Industry/sms_template',
		method: 'post',
		data,
	});
}
/**
 * @description 获取短信模板详情
 * @param {string} id
 */
export const getSmsDetail = (id: string) => {
	return request({
		url: `/api/v1/Industry/sms_template/${id}`,
		method: 'get',
	});
}
/**
 * @description 删除短信模板
 * @param {object} data
 */
export const delSmsTemplate = (data: object) => {
	return request({
		url: '/api/v1/Industry/sms_template',
		method: 'delete',
		data,
	});
}
/**
 * @description 更新短信模板
 * @param {object} data
 */
export const editSms = (data: object) => {
	return request({
		url: '/api/v1/Industry/sms_template',
		method: 'put',
		data,
	});
}
/**
 * @description 获取区域从业人员列表
 * @param {object} params
 */
export const getAreaUserList = (params?: object) => {
	return request({
		url: '/api/v1/Industry/practitioner',
		method: 'get',
		params,
	});
}
/**
 * @description 获取区域从业人员列表导出
 * @param {object} data
 */
export const getAreaUserListExport = (data: object) => {
	return request({
		url: '/api/v1/Industry/practitioner/export_excel',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
}
/**
 * @description 新增区域从业人员 基础信息
 * @param {string} params
 */
export const baseAreaUser = (params?: object) => {
	return request({
		url: '/api/v1/Industry/practitioner/basedata',
		method: 'get',
		params,
	});
}
/**
 * @description 新增区域从业人员
 * @param {object} data
 */
export const addAreaUser = (data: object) => {
	return request({
		url: '/api/v1/Industry/practitioner',
		method: 'post',
		data,
	});
}
/**
 * @description 获取区域从业人员详情
 * @param {string} id
 */
export const getAreaUserDetail = (id: string) => {
	return request({
		url: `/api/v1/Industry/practitioner/${id}`,
		method: 'get',
	});
}
/**
 * @description 更新区域从业人员
 * @param {object} data
 */
export const editAreaUser = (data: object) => {
	return request({
		url: '/api/v1/Industry/practitioner',
		method: 'put',
		data,
	});
}
/**
 * @description 删除区域从业人员
 * @param {object} data
 */
export const delAreaUser = (data: object) => {
	return request({
		url: '/api/v1/Industry/practitioner',
		method: 'delete',
		data,
	});
}
/**
 * @description 获取志愿者上报列表
 * @param {object} params
 */
export const getReportList = (params?: object) => {
	return request({
		url: '/api/v1/Industry/volunteer/report',
		method: 'get',
		params,
	});
}
/**
 * @description 志愿者上报列表导出
 * @param {object} data
 */
export const getReportListExport = (data: object) => {
	return request({
		url: '/api/v1/Industry/volunteer/report/export_excel',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
}
/**
 * @description 获取志愿者列表
 * @param {object} params
 */
export const getVolunteerList = (params?: object) => {
	return request({
		url: '/api/v1/Industry/volunteer',
		method: 'get',
		params,
	});
}
/**
 * @description 志愿者列表导出
 * @param {object} data
 */
export const getVolunteerListExport = (data: object) => {
	return request({
		url: '/api/v1/Industry/volunteer/export_excel',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
}
/**
 * @description 新增志愿者
 * @param {object} data
 */
export const addVolunteer = (data: object) => {
	return request({
		url: '/api/v1/Industry/volunteer',
		method: 'post',
		data,
	});
}
/**
 * @description 获取志愿者详情
 * @param {string} id
 */
export const getVolunteerDetail = (id: string) => {
	return request({
		url: `/api/v1/Industry/volunteer/${id}`,
		method: 'get',
	});
}
/**
 * @description  编辑志愿者
 * @param {object} data
 */
export const editVolunteer = (data: object) => {
	return request({
		url: '/api/v1/Industry/volunteer',
		method: 'put',
		data,
	});
}
/**
 * @description  删除志愿者
 * @param {object} data
 */
export const delVolunteer = (data: object) => {
	return request({
		url: '/api/v1/Industry/volunteer',
		method: 'delete',
		data,
	});
}
/**
 * @description 行业修改记录
 * @param {object} params
 */
export const getIndustryEditRecord = (params?: object) => {
	return request({
		url: '/api/v1/Industry/order/industry/log',
		method: 'get',
		params,
	});
}
/**
 * @description 行业修改记录导出
 * @param {object} data
 */
export const getIndustryEditRecordExport = (data: object) => {
	return request({
		url: '/api/v1/Industry/order/industry/log/export_excel',
		method: 'post',
		data,
		responseType: 'blob',
	}, {
		reduce_data_format: false
	});
}