/*
 * @Author: zc
 * @description 随手拍-红包审批
 */
import request from '@/utils/request';
/**
 * @description 获取市民红包审批列表基础信息
 * @param {object} params
 */
export const getCitizenRedEnvelopeApprovalBaseData = (params?: object) => {
	return request({
		url: `/api/v1/RedPack/audit/basedata`,
		method: 'get',
		params,
	});
};
/**
 * @description 获取市民红包审批列表
 * @param {object} params
 */
export const getCitizenRedEnvelopeApprovalList = (params?: object) => {
	return request({
		url: `/api/v1/RedPack/audit`,
		method: 'get',
		params,
	});
};
/**
 * @description 市民红包审批列表导出
 * @param {object} data
 */
export const getCitizenRedEnvelopeApprovalExport = (data: object) => {
	return request(
		{
			url: `/api/v1/RedPack/audit/export_excel`,
			method: 'post',
			data,
			responseType: 'blob',
		},
		{
			reduce_data_format: false,
		}
	);
};
/**
 * @description 获取市民红包审批详情
 * @param {object} id
 */
export const getCitizenRedEnvelopeApprovalDetail = (id?: string) => {
	return request({
		url: `/api/v1/RedPack/audit/${id}`,
		method: 'get',
	});
};
/**
 * @description 获取市民红包审批短信模板
 * @param {object} params
 */
export const getCitizenRedEnvelopeApprovalSmsTemplate = (params?: object) => {
	return request({
		url: `/api/v1/RedPack/audit/sms_template`,
		method: 'get',
		params,
	});
};
/**
 * @description 获取市民红包审批基础信息
 * @param {object} params
 */
export const getCitizenRedEnvelopeApprovalBaseInfo = (params?: object) => {
	return request({
		url: `/api/v1/RedPack/audit/baseinfo`,
		method: 'get',
		params,
	});
};
/**
 * @description 市民红包审批或者拒绝
 * @param {object} data
 */
export const citizenRedEnvelopeApproval = (data: object) => {
	return request({
		url: `/api/v1/RedPack/audit`,
		method: 'put',
		data,
	});
};
/**
 * @description 获取红包审批特提信息
 * @param {string} id
 */
export const getCitizenRedEnvelopeApprovalSpecialInfo = (id?: string) => {
	return request({
		url: `/api/v1/RedPack/audit/back/${id}`,
		method: 'get',
	});
};
/**
 * @description 添加备注页面基础信息
 * @param {object} params
 */
export const getCitizenRedEnvelopeApprovalRemarkBaseInfo = (params?: object) => {
	return request({
		url: `/api/v1/RedPack/audit/remark/basedata`,
		method: 'get',
		params,
	});
};
/**
 * @description 添加备注
 * @param {object} data
 */
export const citizenRedEnvelopeApprovalRemark = (data: object) => {
	return request({
		url: `/api/v1/RedPack/audit/remark`,
		method: 'put',
		data,
	});
};
/**
 * @description 添加补充发放信息基础信息
 * @param {object} id
 */
export const getCitizenRedEnvelopeApprovalAdditionalBaseInfo = (id?: string) => {
	return request({
		url: `/api/v1/RedPack/record/basedata/${id}`,
		method: 'get',
	});
};
/**
 * @description 添加补充发放信息
 * @param {object} data
 */
export const citizenRedEnvelopeApprovalAdditional = (data: object) => {
	return request({
		url: `/api/v1/RedPack/record`,
		method: 'put',
		data,
	});
};
/**
 * @description 获取网格员红包审批列表
 * @param {object} params
 */
export const getGridRedEnvelopeApprovalList = (params?: object) => {
	return request({
		url: `/api/v1/RedPack/audit/guider`,
		method: 'get',
		params,
	});
};
/**
 * @description 网格员红包审批列表导出
 * @param {object} data
 */
export const getGridRedEnvelopeApprovalListExport = (data: object) => {
	return request(
		{
			url: `/api/v1/RedPack/audit/guider/export_excel`,
			method: 'post',
			data,
			responseType: 'blob',
		},
		{
			reduce_data_format: false,
		}
	);
};
/**
 * @description 获取网格员红包审批详情
 * @param {object} id
 */
export const getGridRedEnvelopeApprovalDetail = (id?: string) => {
	return request({
		url: `/api/v1/RedPack/audit/guider/${id}`,
		method: 'get',
	});
};
/**
 * @description 网格员红包审批或者拒绝
 * @param {object} data
 */
export const gridRedEnvelopeApproval = (data: object) => {
	return request({
		url: `/api/v1/RedPack/audit/guider`,
		method: 'put',
		data,
	});
};
/**
 * @description 获取特殊红包审批列表
 * @param {object} params
 */
export const getSpecialRedEnvelopeApprovalList = (params?: object) => {
	return request({
		url: `/api/v1/RedPack/special`,
		method: 'get',
		params,
	});
};
/**
 * @description 特殊红包审批列表导出
 * @param {object} data
 */
export const getSpecialRedEnvelopeApprovalListExport = (data: object) => {
	return request(
		{
			url: `/api/v1/RedPack/special/export_excel`,
			method: 'post',
			data,
			responseType: 'blob',
		},
		{
			reduce_data_format: false,
		}
	);
};
/**
 * @description 获取特殊红包审批基础参数
 * @param {object} id
 */
export const getSpecialRedEnvelopeApprovalBaseInfo = (id?: string) => {
	return request({
		url: `/api/v1/RedPack/audit/special/${id}`,
		method: 'get',
	});
};
/**
 * @description 特殊红包审批
 * @param {object} data
 */
export const specialRedEnvelopeApproval = (data: object) => {
	return request({
		url: `/api/v1/RedPack/audit/special`,
		method: 'put',
		data,
	});
};
/**
 * @description 获取特殊红包补充基础参数
 * @param {object} id
 */
export const getSpecialRedEnvelopeApprovalAdditionalBaseInfo = (id?: string) => {
	return request({
		url: `/api/v1/RedPack/record/basedata/${id}`,
		method: 'get',
	});
};
/**
 * @description 特殊红包补充
 * @param {object} data
 */
export const specialRedEnvelopeApprovalAdditional = (data: object) => {
	return request({
		url: `/api/v1/RedPack/record/special`,
		method: 'put',
		data,
	});
};
/**
 * @description 特殊红包审批撤销
 * @param {object} data
 */
export const specialRedEnvelopeApprovalCancel = (data: object) => {
	return request({
		url: `/api/v1/RedPack/audit/special/revocation`,
		method: 'put',
		data,
	});
}
