/*
 * @Author: zc
 * @description 系统管理 - 组织架构
 */
import request from '@/utils/request';
/**
 * @description 基础数据
 * @return {*}
 */
export const baseData = () => {
	return request({
		url: `/api/v1/Org/base-data`,
		method: 'get',
	});
};
/**
 * @description 获取组织架构列表
 * @param {object} params
 * @return {*}
 */
export const getOrgList = (params?: object) => {
	return request({
		url: '/api/v1/Org/getorgjson',
		method: 'get',
		params,
	});
};
/**
 * @description 获取组织架构列表(根据当前登录用户查询 中心看所有  部门看自己部门级下级部门)
 * @param {object} params
 * @return {*}
 */
export const getOrgListByUser = (params?: object) => {
	return request({
		url: '/api/v1/Org/getorgjsonforuser',
		method: 'get',
		params,
	});
};
/**
 * @description 获取组织架构列表 导出
 * @param {object} data
 * @return {*}
 */
export const getOrgListExport = (data: object) => {
	return request({
		url: '/api/v1/Org/getorgjsonforuser/export',
		method: 'post',
			data,
			responseType: 'blob',
		},
		{
			reduce_data_format: false,
		}
	);
};
/**
 * @description 新增组织
 * @return {*}
 * @param data
 */
export const addOrg = (data: object) => {
	return request({
		url: '/api/v1/Org',
		method: 'post',
		data,
	});
};
/**
 * @description 更新组织修改 不支持修改上级
 * @return {*}
 * @param data
 */
export const updateOrg = (data: object) => {
	return request({
		url: '/api/v1/Org',
		method: 'put',
		data,
	});
};
/**
 * @description 获取组织详情根据id
 * @param {object} id
 * @return {*}
 */
export const getOrgById = (id: string) => {
	return request({
		url: `/api/v1/Org/getorg/${id}`,
		method: 'get',
	});
};
/**
 * @description 删除组织
 * @return {*}
 * @param id
 */
export const delOrg = (id: string) => {
	return request({
		url: `/api/v1/Org/delete-org/${id}`,
		method: 'delete',
	});
};